Configuration Reference — Inmanta 2017.1.1 documentation

# Configuration Reference

This document lists all options for the inmanta server and inmanta agent.

The options are listed per config section.

## agent_rest_transport

`host`

  Type: | str
  Default: | `localhost`

  IP address or hostname of the server

`password`

  Type: | optional str

  Password used to connect to the server

`port`

  Type: | int
  Default: | `8888`

  Server port

`ssl`

  Type: | bool

  Connect using SSL?

`ssl-ca-cert-file`

  Type: | optional str

  CA cert file used to validate the server certificate against

`username`

  Type: | optional str

  Username used to connect to the server

## client_rest_transport

`host`

  Type: | str
  Default: | `localhost`

  IP address or hostname of the server

`password`

  Type: | optional str

  Password used to connect to the server

`port`

  Type: | int
  Default: | `8888`

  Server port

`ssl`

  Type: | bool

  Connect using SSL?

`ssl-ca-cert-file`

  Type: | optional str

  CA cert file used to validate the server certificate against

`username`

  Type: | optional str

  Username used to connect to the server

## cmdline_rest_transport

`host`

  Type: | str
  Default: | `localhost`

  IP address or hostname of the server

`password`

  Type: | optional str

  Password used to connect to the server

`port`

  Type: | int
  Default: | `8888`

  Server port

`ssl`

  Type: | bool

  Connect using SSL?

`ssl-ca-cert-file`

  Type: | optional str

  CA cert file used to validate the server certificate against

`username`

  Type: | optional str

  Username used to connect to the server

## compiler_rest_transport

`host`

  Type: | str
  Default: | `localhost`

  IP address or hostname of the server

`password`

  Type: | optional str

  Password used to connect to the server

`port`

  Type: | int
  Default: | `8888`

  Server port

`ssl`

  Type: | bool

  Connect using SSL?

`ssl-ca-cert-file`

  Type: | optional str

  CA cert file used to validate the server certificate against

`username`

  Type: | optional str

  Username used to connect to the server

## config

`agent-interval`

  Type: | time
  Default: | `600`

  The run interval of the agent. Every run-interval seconds, the agent will check the current state of its resources against to desired state model

`agent-map`

  Type: | map

  mapping between agent names and host names. If an agent is autostarted, its hostname is looked up in this map. If it is not found, the agent name is used as hostname. If the hostname is not localhost or `config.node-name`, ssh is used to start the agent on the appropriate machine example: iaas_openstack=localhost,vm1=192.16.13.2

`agent-names`

  Type: | str
  Default: | `$node-name`

  Names of the agents this instance should deploy configuration for

`agent-reconnect-delay`

  Type: | int
  Default: | `5`

  Time to wait after a failed heartbeat message. DO NOT SET TO 0

`agent-run-at-start`

  Type: | bool

  run the agent at startup, even if a splay time is set

`agent-splay`

  Type: | time
  Default: | `600`

  The splaytime added to the runinterval. Set this to 0 to disable splaytime. At startup the agent will choose a random number between 0 and “agent_splay. It will wait this number of second before performing the first deploy. Each subsequent deploy will start agent-interval seconds after the previous one.

`environment`

  Type: | optional uuid

  The environment this model is associated with

`export`

  Type: | list

  The list of exporters to use

`log-dir`

  Type: | str
  Default: | `/var/log/inmanta`

  The directory where the server stores log file. Currently this is only for the output of embedded agents.

`node-name`

  Type: | str
  Default: | `$ socket.gethostname()`

  Force the hostname of this machine to a specific value

`python-binary`

  Type: | str
  Default: | `python`

  Python binary used to run the remote agent

`server-timeout`

  Type: | time
  Default: | `125`

  Amount of time to wait for a response from the server before we try to reconnect, must be smaller than server.agent-hold

`state-dir`

  Type: | str
  Default: | `/var/lib/inmanta`

  The directory where the server stores its state

## dashboard

`enabled`

  Type: | bool
  Default: | `True`

  Determines whether the server should host the dashboard or not

`path`

  Type: | str
  Default: | `/usr/share/inmanta/dashboard`

  The path on the local file system where the dashboard can be found

## database

`host`

  Type: | str
  Default: | `localhost`

  Hostname or IP of the mongo server

`name`

  Type: | str
  Default: | `inmanta`

  The name of the database on the mongo server

`port`

  Type: | int
  Default: | `27017`

  The port of the mongo server

## server

`agent-autostart`

  Type: | list
  Default: | `iaas_*`

  Which agents can the server start itself? Setting this value to * will match all agents. These agents are started when a dryrun or a deploy is requested.

`agent-hold`

  Type: | time
  Default: | `$ server.agent-timeout*3/4`

  Maximal time the server will hold an agent heartbeat call

`agent-timeout`

  Type: | time
  Default: | `30`

  Time before an agent is considered to be offline

`auto-recompile-wait`

  Type: | time
  Default: | `10`

  The number of seconds to wait before the server may attempt to do a new recompile. Recompiles are triggered after facts updates for example.

`autostart-on-start`

  Type: | bool
  Default: | `True`

  Automatically start agents when the server starts instead of only just in time.

`available-versions-to-keep`

  Type: | int
  Default: | `2`

  On boot and at regular intervals the server will purge versions that have not been deployed. This is the number of most recent undeployed versions to keep available.

`fact-expire`

  Type: | time
  Default: | `3600`

  After how many seconds will discovered facts/parameters expire

`fact-renew`

  Type: | time; < server.fact-expire
  Default: | `$ server.fact-expire/3`

  After how many seconds will discovered facts/parameters be renewed? This value needs to be lower than fact-expire

`fact-resource-block`

  Type: | time
  Default: | `60`

  Minimal time between subsequent requests for the same fact

`no-recompile`

  Type: | bool

  Prevent all server side compiles

`password`

  Type: | optional str

  Password required to connect to this server. Leave blank to disable auth

`purge-versions-interval`

  Type: | time
  Default: | `3600`

  The number of seconds between version purging, see `server.available-versions-to-keep`

`server-address`

  Type: | str
  Default: | `localhost`

  The public ip address of the server. This is required for example to inject the inmanta agent in virtual machines at boot time.

`ssl-cert-file`

  Type: | optional str

  SSL certificate file for the server key. Leave blank to disable SSL

`ssl-key-file`

  Type: | optional str

  Server private key to use for this server Leave blank to disable SSl

`username`

  Type: | optional str

  Username required to connect to this server. Leave blank to disable auth

`wait-after-param`

  Type: | time
  Default: | `5`

  Time to wait before recompile after new paramters have been received

## server_rest_transport

`port`

  Type: | str
  Default: | `8888`

  The port on which the server listens for connections

## unknown_handler

`default`

  Type: | str
  Default: | `prune-agent`

  default method to handle unknown values